# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: drucker.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='drucker.proto',
  package='drucker',
  syntax='proto3',
  serialized_pb=_b('\n\rdrucker.proto\x12\x07\x64rucker\x1a google/protobuf/descriptor.proto\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"\x8d\x01\n\x13HealthCheckResponse\x12:\n\x06status\x18\x01 \x01(\x0e\x32*.drucker.HealthCheckResponse.ServingStatus\":\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\"\x18\n\tArrString\x12\x0b\n\x03val\x18\x01 \x03(\t\"$\n\x06Tensor\x12\r\n\x05shape\x18\x01 \x03(\x05\x12\x0b\n\x03val\x18\x02 \x03(\x01\"V\n\x02IO\x12!\n\x06tensor\x18\x01 \x01(\x0b\x32\x0f.drucker.TensorH\x00\x12!\n\x03str\x18\x02 \x01(\x0b\x32\x12.drucker.ArrStringH\x00\x42\n\n\x08io_oneof\"\x14\n\x12ServiceInfoRequest\"\\\n\x13ServiceInfoResponse\x12\x18\n\x10\x61pplication_name\x18\x01 \x01(\t\x12\x14\n\x0cservice_name\x18\x02 \x01(\t\x12\x15\n\rservice_level\x18\x03 \x01(\t\"0\n\x12UploadModelRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"\"\n\x12SwitchModelRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"0\n\rModelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\">\n\x1bUploadEvaluationDataRequest\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x11\n\tdata_path\x18\x02 \x01(\t\"?\n\x1cUploadEvaluationDataResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0f\n\x07message\x18\x02 \x01(\t\"P\n\x14\x45valuateModelRequest\x12\x10\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x02\x18\x01\x12\x11\n\tdata_path\x18\x02 \x01(\t\x12\x13\n\x0bresult_path\x18\x03 \x01(\t\"\xcc\x01\n\x11\x45valuationMetrics\x12\x0b\n\x03num\x18\x01 \x01(\x05\x12\x10\n\x08\x61\x63\x63uracy\x18\x02 \x01(\x02\x12\x11\n\tprecision\x18\x03 \x03(\x02\x12\x0e\n\x06recall\x18\x04 \x03(\x02\x12\x0e\n\x06\x66value\x18\x05 \x03(\x02\x12\x36\n\x06option\x18\x06 \x03(\x0b\x32&.drucker.EvaluationMetrics.OptionEntry\x1a-\n\x0bOptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"D\n\x15\x45valuateModelResponse\x12+\n\x07metrics\x18\x01 \x01(\x0b\x32\x1a.drucker.EvaluationMetrics\",\n\x17\x45valuationResultRequest\x12\x11\n\tdata_path\x18\x01 \x01(\t\"\x84\x02\n\x18\x45valuationResultResponse\x12+\n\x07metrics\x18\x01 \x01(\x0b\x32\x1a.drucker.EvaluationMetrics\x12\x38\n\x06\x64\x65tail\x18\x02 \x03(\x0b\x32(.drucker.EvaluationResultResponse.Detail\x1a\x80\x01\n\x06\x44\x65tail\x12\x1a\n\x05input\x18\x01 \x01(\x0b\x32\x0b.drucker.IO\x12\x1a\n\x05label\x18\x02 \x01(\x0b\x32\x0b.drucker.IO\x12\x1b\n\x06output\x18\x03 \x01(\x0b\x32\x0b.drucker.IO\x12\r\n\x05score\x18\x04 \x03(\x02\x12\x12\n\nis_correct\x18\x05 \x01(\x08\"\x15\n\x06Option\x12\x0b\n\x03val\x18\x01 \x01(\t\"=\n\x0bStringInput\x12\r\n\x05input\x18\x01 \x01(\t\x12\x1f\n\x06option\x18\x02 \x01(\x0b\x32\x0f.drucker.Option\"<\n\nBytesInput\x12\r\n\x05input\x18\x01 \x01(\x0c\x12\x1f\n\x06option\x18\x02 \x01(\x0b\x32\x0f.drucker.Option\"=\n\x0b\x41rrIntInput\x12\r\n\x05input\x18\x01 \x03(\x05\x12\x1f\n\x06option\x18\x02 \x01(\x0b\x32\x0f.drucker.Option\"?\n\rArrFloatInput\x12\r\n\x05input\x18\x01 \x03(\x02\x12\x1f\n\x06option\x18\x02 \x01(\x0b\x32\x0f.drucker.Option\"@\n\x0e\x41rrStringInput\x12\r\n\x05input\x18\x01 \x03(\t\x12\x1f\n\x06option\x18\x02 \x01(\x0b\x32\x0f.drucker.Option\"N\n\x0cStringOutput\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x1f\n\x06option\x18\x03 \x01(\x0b\x32\x0f.drucker.Option\"M\n\x0b\x42ytesOutput\x12\x0e\n\x06output\x18\x01 \x01(\x0c\x12\r\n\x05score\x18\x02 \x01(\x02\x12\x1f\n\x06option\x18\x03 \x01(\x0b\x32\x0f.drucker.Option\"N\n\x0c\x41rrIntOutput\x12\x0e\n\x06output\x18\x01 \x03(\x05\x12\r\n\x05score\x18\x02 \x03(\x02\x12\x1f\n\x06option\x18\x03 \x01(\x0b\x32\x0f.drucker.Option\"P\n\x0e\x41rrFloatOutput\x12\x0e\n\x06output\x18\x01 \x03(\x02\x12\r\n\x05score\x18\x02 \x03(\x02\x12\x1f\n\x06option\x18\x03 \x01(\x0b\x32\x0f.drucker.Option\"Q\n\x0f\x41rrStringOutput\x12\x0e\n\x06output\x18\x01 \x03(\t\x12\r\n\x05score\x18\x02 \x03(\x02\x12\x1f\n\x06option\x18\x03 \x01(\x0b\x32\x0f.drucker.Option*)\n\x0f\x45numVersionInfo\x12\x06\n\x02v0\x10\x00\x12\x06\n\x02v1\x10\x01\x12\x06\n\x02v2\x10\x02\x32L\n\x06Health\x12\x42\n\x05\x43heck\x12\x1b.drucker.HealthCheckRequest\x1a\x1c.drucker.HealthCheckResponse2\x86\x04\n\x10\x44ruckerDashboard\x12J\n\x0bServiceInfo\x12\x1b.drucker.ServiceInfoRequest\x1a\x1c.drucker.ServiceInfoResponse\"\x00\x12\x46\n\x0bUploadModel\x12\x1b.drucker.UploadModelRequest\x1a\x16.drucker.ModelResponse\"\x00(\x01\x12\x44\n\x0bSwitchModel\x12\x1b.drucker.SwitchModelRequest\x1a\x16.drucker.ModelResponse\"\x00\x12g\n\x14UploadEvaluationData\x12$.drucker.UploadEvaluationDataRequest\x1a%.drucker.UploadEvaluationDataResponse\"\x00(\x01\x12R\n\rEvaluateModel\x12\x1d.drucker.EvaluateModelRequest\x1a\x1e.drucker.EvaluateModelResponse\"\x00(\x01\x12[\n\x10\x45valuationResult\x12 .drucker.EvaluationResultRequest\x1a!.drucker.EvaluationResultResponse\"\x00\x30\x01\x32\xfb\x0e\n\rDruckerWorker\x12\x46\n\x15Predict_String_String\x12\x14.drucker.StringInput\x1a\x15.drucker.StringOutput\"\x00\x12\x46\n\x14Predict_String_Bytes\x12\x14.drucker.StringInput\x1a\x14.drucker.BytesOutput\"\x00\x30\x01\x12\x46\n\x15Predict_String_ArrInt\x12\x14.drucker.StringInput\x1a\x15.drucker.ArrIntOutput\"\x00\x12J\n\x17Predict_String_ArrFloat\x12\x14.drucker.StringInput\x1a\x17.drucker.ArrFloatOutput\"\x00\x12L\n\x18Predict_String_ArrString\x12\x14.drucker.StringInput\x1a\x18.drucker.ArrStringOutput\"\x00\x12\x46\n\x14Predict_Bytes_String\x12\x13.drucker.BytesInput\x1a\x15.drucker.StringOutput\"\x00(\x01\x12\x46\n\x13Predict_Bytes_Bytes\x12\x13.drucker.BytesInput\x1a\x14.drucker.BytesOutput\"\x00(\x01\x30\x01\x12\x46\n\x14Predict_Bytes_ArrInt\x12\x13.drucker.BytesInput\x1a\x15.drucker.ArrIntOutput\"\x00(\x01\x12J\n\x16Predict_Bytes_ArrFloat\x12\x13.drucker.BytesInput\x1a\x17.drucker.ArrFloatOutput\"\x00(\x01\x12L\n\x17Predict_Bytes_ArrString\x12\x13.drucker.BytesInput\x1a\x18.drucker.ArrStringOutput\"\x00(\x01\x12\x46\n\x15Predict_ArrInt_String\x12\x14.drucker.ArrIntInput\x1a\x15.drucker.StringOutput\"\x00\x12\x46\n\x14Predict_ArrInt_Bytes\x12\x14.drucker.ArrIntInput\x1a\x14.drucker.BytesOutput\"\x00\x30\x01\x12\x46\n\x15Predict_ArrInt_ArrInt\x12\x14.drucker.ArrIntInput\x1a\x15.drucker.ArrIntOutput\"\x00\x12J\n\x17Predict_ArrInt_ArrFloat\x12\x14.drucker.ArrIntInput\x1a\x17.drucker.ArrFloatOutput\"\x00\x12L\n\x18Predict_ArrInt_ArrString\x12\x14.drucker.ArrIntInput\x1a\x18.drucker.ArrStringOutput\"\x00\x12J\n\x17Predict_ArrFloat_String\x12\x16.drucker.ArrFloatInput\x1a\x15.drucker.StringOutput\"\x00\x12J\n\x16Predict_ArrFloat_Bytes\x12\x16.drucker.ArrFloatInput\x1a\x14.drucker.BytesOutput\"\x00\x30\x01\x12J\n\x17Predict_ArrFloat_ArrInt\x12\x16.drucker.ArrFloatInput\x1a\x15.drucker.ArrIntOutput\"\x00\x12N\n\x19Predict_ArrFloat_ArrFloat\x12\x16.drucker.ArrFloatInput\x1a\x17.drucker.ArrFloatOutput\"\x00\x12P\n\x1aPredict_ArrFloat_ArrString\x12\x16.drucker.ArrFloatInput\x1a\x18.drucker.ArrStringOutput\"\x00\x12L\n\x18Predict_ArrString_String\x12\x17.drucker.ArrStringInput\x1a\x15.drucker.StringOutput\"\x00\x12L\n\x17Predict_ArrString_Bytes\x12\x17.drucker.ArrStringInput\x1a\x14.drucker.BytesOutput\"\x00\x30\x01\x12L\n\x18Predict_ArrString_ArrInt\x12\x17.drucker.ArrStringInput\x1a\x15.drucker.ArrIntOutput\"\x00\x12P\n\x1aPredict_ArrString_ArrFloat\x12\x17.drucker.ArrStringInput\x1a\x17.drucker.ArrFloatOutput\"\x00\x12R\n\x1bPredict_ArrString_ArrString\x12\x17.drucker.ArrStringInput\x1a\x18.drucker.ArrStringOutput\"\x00:B\n\x1a\x64rucker_grpc_proto_version\x12\x1c.google.protobuf.FileOptions\x18\xd0\x86\x03 \x01(\tB\x06\x82\xb5\x18\x02v2b\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])

_ENUMVERSIONINFO = _descriptor.EnumDescriptor(
  name='EnumVersionInfo',
  full_name='drucker.EnumVersionInfo',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='v0', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='v1', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='v2', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2190,
  serialized_end=2231,
)
_sym_db.RegisterEnumDescriptor(_ENUMVERSIONINFO)

EnumVersionInfo = enum_type_wrapper.EnumTypeWrapper(_ENUMVERSIONINFO)
v0 = 0
v1 = 1
v2 = 2

DRUCKER_GRPC_PROTO_VERSION_FIELD_NUMBER = 50000
drucker_grpc_proto_version = _descriptor.FieldDescriptor(
  name='drucker_grpc_proto_version', full_name='drucker.drucker_grpc_proto_version', index=0,
  number=50000, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=_b("").decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  options=None, file=DESCRIPTOR)

_HEALTHCHECKRESPONSE_SERVINGSTATUS = _descriptor.EnumDescriptor(
  name='ServingStatus',
  full_name='drucker.HealthCheckResponse.ServingStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SERVING', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_SERVING', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=183,
  serialized_end=241,
)
_sym_db.RegisterEnumDescriptor(_HEALTHCHECKRESPONSE_SERVINGSTATUS)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='HealthCheckRequest',
  full_name='drucker.HealthCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='drucker.HealthCheckRequest.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=60,
  serialized_end=97,
)


_HEALTHCHECKRESPONSE = _descriptor.Descriptor(
  name='HealthCheckResponse',
  full_name='drucker.HealthCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='drucker.HealthCheckResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEALTHCHECKRESPONSE_SERVINGSTATUS,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=241,
)


_ARRSTRING = _descriptor.Descriptor(
  name='ArrString',
  full_name='drucker.ArrString',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='drucker.ArrString.val', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=267,
)


_TENSOR = _descriptor.Descriptor(
  name='Tensor',
  full_name='drucker.Tensor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='drucker.Tensor.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='drucker.Tensor.val', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=305,
)


_IO = _descriptor.Descriptor(
  name='IO',
  full_name='drucker.IO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tensor', full_name='drucker.IO.tensor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='str', full_name='drucker.IO.str', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='io_oneof', full_name='drucker.IO.io_oneof',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=307,
  serialized_end=393,
)


_SERVICEINFOREQUEST = _descriptor.Descriptor(
  name='ServiceInfoRequest',
  full_name='drucker.ServiceInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=395,
  serialized_end=415,
)


_SERVICEINFORESPONSE = _descriptor.Descriptor(
  name='ServiceInfoResponse',
  full_name='drucker.ServiceInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='application_name', full_name='drucker.ServiceInfoResponse.application_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_name', full_name='drucker.ServiceInfoResponse.service_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_level', full_name='drucker.ServiceInfoResponse.service_level', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=509,
)


_UPLOADMODELREQUEST = _descriptor.Descriptor(
  name='UploadModelRequest',
  full_name='drucker.UploadModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='drucker.UploadModelRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='drucker.UploadModelRequest.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=511,
  serialized_end=559,
)


_SWITCHMODELREQUEST = _descriptor.Descriptor(
  name='SwitchModelRequest',
  full_name='drucker.SwitchModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='drucker.SwitchModelRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=561,
  serialized_end=595,
)


_MODELRESPONSE = _descriptor.Descriptor(
  name='ModelResponse',
  full_name='drucker.ModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='drucker.ModelResponse.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='drucker.ModelResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=645,
)


_UPLOADEVALUATIONDATAREQUEST = _descriptor.Descriptor(
  name='UploadEvaluationDataRequest',
  full_name='drucker.UploadEvaluationDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='drucker.UploadEvaluationDataRequest.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_path', full_name='drucker.UploadEvaluationDataRequest.data_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=709,
)


_UPLOADEVALUATIONDATARESPONSE = _descriptor.Descriptor(
  name='UploadEvaluationDataResponse',
  full_name='drucker.UploadEvaluationDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='drucker.UploadEvaluationDataResponse.status', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='drucker.UploadEvaluationDataResponse.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=774,
)


_EVALUATEMODELREQUEST = _descriptor.Descriptor(
  name='EvaluateModelRequest',
  full_name='drucker.EvaluateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='drucker.EvaluateModelRequest.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data_path', full_name='drucker.EvaluateModelRequest.data_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result_path', full_name='drucker.EvaluateModelRequest.result_path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=776,
  serialized_end=856,
)


_EVALUATIONMETRICS_OPTIONENTRY = _descriptor.Descriptor(
  name='OptionEntry',
  full_name='drucker.EvaluationMetrics.OptionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='drucker.EvaluationMetrics.OptionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='drucker.EvaluationMetrics.OptionEntry.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1063,
)

_EVALUATIONMETRICS = _descriptor.Descriptor(
  name='EvaluationMetrics',
  full_name='drucker.EvaluationMetrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='drucker.EvaluationMetrics.num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='drucker.EvaluationMetrics.accuracy', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precision', full_name='drucker.EvaluationMetrics.precision', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recall', full_name='drucker.EvaluationMetrics.recall', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fvalue', full_name='drucker.EvaluationMetrics.fvalue', index=4,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.EvaluationMetrics.option', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVALUATIONMETRICS_OPTIONENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=1063,
)


_EVALUATEMODELRESPONSE = _descriptor.Descriptor(
  name='EvaluateModelResponse',
  full_name='drucker.EvaluateModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='drucker.EvaluateModelResponse.metrics', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1133,
)


_EVALUATIONRESULTREQUEST = _descriptor.Descriptor(
  name='EvaluationResultRequest',
  full_name='drucker.EvaluationResultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_path', full_name='drucker.EvaluationResultRequest.data_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1179,
)


_EVALUATIONRESULTRESPONSE_DETAIL = _descriptor.Descriptor(
  name='Detail',
  full_name='drucker.EvaluationResultResponse.Detail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.EvaluationResultResponse.Detail.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='drucker.EvaluationResultResponse.Detail.label', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.EvaluationResultResponse.Detail.output', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.EvaluationResultResponse.Detail.score', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_correct', full_name='drucker.EvaluationResultResponse.Detail.is_correct', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1314,
  serialized_end=1442,
)

_EVALUATIONRESULTRESPONSE = _descriptor.Descriptor(
  name='EvaluationResultResponse',
  full_name='drucker.EvaluationResultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='drucker.EvaluationResultResponse.metrics', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='drucker.EvaluationResultResponse.detail', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_EVALUATIONRESULTRESPONSE_DETAIL, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1182,
  serialized_end=1442,
)


_OPTION = _descriptor.Descriptor(
  name='Option',
  full_name='drucker.Option',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='drucker.Option.val', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1465,
)


_STRINGINPUT = _descriptor.Descriptor(
  name='StringInput',
  full_name='drucker.StringInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.StringInput.input', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.StringInput.option', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1528,
)


_BYTESINPUT = _descriptor.Descriptor(
  name='BytesInput',
  full_name='drucker.BytesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.BytesInput.input', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.BytesInput.option', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1590,
)


_ARRINTINPUT = _descriptor.Descriptor(
  name='ArrIntInput',
  full_name='drucker.ArrIntInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.ArrIntInput.input', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrIntInput.option', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1592,
  serialized_end=1653,
)


_ARRFLOATINPUT = _descriptor.Descriptor(
  name='ArrFloatInput',
  full_name='drucker.ArrFloatInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.ArrFloatInput.input', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrFloatInput.option', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1718,
)


_ARRSTRINGINPUT = _descriptor.Descriptor(
  name='ArrStringInput',
  full_name='drucker.ArrStringInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='drucker.ArrStringInput.input', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrStringInput.option', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1720,
  serialized_end=1784,
)


_STRINGOUTPUT = _descriptor.Descriptor(
  name='StringOutput',
  full_name='drucker.StringOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.StringOutput.output', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.StringOutput.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.StringOutput.option', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1786,
  serialized_end=1864,
)


_BYTESOUTPUT = _descriptor.Descriptor(
  name='BytesOutput',
  full_name='drucker.BytesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.BytesOutput.output', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.BytesOutput.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.BytesOutput.option', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=1943,
)


_ARRINTOUTPUT = _descriptor.Descriptor(
  name='ArrIntOutput',
  full_name='drucker.ArrIntOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.ArrIntOutput.output', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.ArrIntOutput.score', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrIntOutput.option', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1945,
  serialized_end=2023,
)


_ARRFLOATOUTPUT = _descriptor.Descriptor(
  name='ArrFloatOutput',
  full_name='drucker.ArrFloatOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.ArrFloatOutput.output', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.ArrFloatOutput.score', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrFloatOutput.option', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2105,
)


_ARRSTRINGOUTPUT = _descriptor.Descriptor(
  name='ArrStringOutput',
  full_name='drucker.ArrStringOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='output', full_name='drucker.ArrStringOutput.output', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='score', full_name='drucker.ArrStringOutput.score', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='drucker.ArrStringOutput.option', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2107,
  serialized_end=2188,
)

_HEALTHCHECKRESPONSE.fields_by_name['status'].enum_type = _HEALTHCHECKRESPONSE_SERVINGSTATUS
_HEALTHCHECKRESPONSE_SERVINGSTATUS.containing_type = _HEALTHCHECKRESPONSE
_IO.fields_by_name['tensor'].message_type = _TENSOR
_IO.fields_by_name['str'].message_type = _ARRSTRING
_IO.oneofs_by_name['io_oneof'].fields.append(
  _IO.fields_by_name['tensor'])
_IO.fields_by_name['tensor'].containing_oneof = _IO.oneofs_by_name['io_oneof']
_IO.oneofs_by_name['io_oneof'].fields.append(
  _IO.fields_by_name['str'])
_IO.fields_by_name['str'].containing_oneof = _IO.oneofs_by_name['io_oneof']
_EVALUATIONMETRICS_OPTIONENTRY.containing_type = _EVALUATIONMETRICS
_EVALUATIONMETRICS.fields_by_name['option'].message_type = _EVALUATIONMETRICS_OPTIONENTRY
_EVALUATEMODELRESPONSE.fields_by_name['metrics'].message_type = _EVALUATIONMETRICS
_EVALUATIONRESULTRESPONSE_DETAIL.fields_by_name['input'].message_type = _IO
_EVALUATIONRESULTRESPONSE_DETAIL.fields_by_name['label'].message_type = _IO
_EVALUATIONRESULTRESPONSE_DETAIL.fields_by_name['output'].message_type = _IO
_EVALUATIONRESULTRESPONSE_DETAIL.containing_type = _EVALUATIONRESULTRESPONSE
_EVALUATIONRESULTRESPONSE.fields_by_name['metrics'].message_type = _EVALUATIONMETRICS
_EVALUATIONRESULTRESPONSE.fields_by_name['detail'].message_type = _EVALUATIONRESULTRESPONSE_DETAIL
_STRINGINPUT.fields_by_name['option'].message_type = _OPTION
_BYTESINPUT.fields_by_name['option'].message_type = _OPTION
_ARRINTINPUT.fields_by_name['option'].message_type = _OPTION
_ARRFLOATINPUT.fields_by_name['option'].message_type = _OPTION
_ARRSTRINGINPUT.fields_by_name['option'].message_type = _OPTION
_STRINGOUTPUT.fields_by_name['option'].message_type = _OPTION
_BYTESOUTPUT.fields_by_name['option'].message_type = _OPTION
_ARRINTOUTPUT.fields_by_name['option'].message_type = _OPTION
_ARRFLOATOUTPUT.fields_by_name['option'].message_type = _OPTION
_ARRSTRINGOUTPUT.fields_by_name['option'].message_type = _OPTION
DESCRIPTOR.message_types_by_name['HealthCheckRequest'] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['HealthCheckResponse'] = _HEALTHCHECKRESPONSE
DESCRIPTOR.message_types_by_name['ArrString'] = _ARRSTRING
DESCRIPTOR.message_types_by_name['Tensor'] = _TENSOR
DESCRIPTOR.message_types_by_name['IO'] = _IO
DESCRIPTOR.message_types_by_name['ServiceInfoRequest'] = _SERVICEINFOREQUEST
DESCRIPTOR.message_types_by_name['ServiceInfoResponse'] = _SERVICEINFORESPONSE
DESCRIPTOR.message_types_by_name['UploadModelRequest'] = _UPLOADMODELREQUEST
DESCRIPTOR.message_types_by_name['SwitchModelRequest'] = _SWITCHMODELREQUEST
DESCRIPTOR.message_types_by_name['ModelResponse'] = _MODELRESPONSE
DESCRIPTOR.message_types_by_name['UploadEvaluationDataRequest'] = _UPLOADEVALUATIONDATAREQUEST
DESCRIPTOR.message_types_by_name['UploadEvaluationDataResponse'] = _UPLOADEVALUATIONDATARESPONSE
DESCRIPTOR.message_types_by_name['EvaluateModelRequest'] = _EVALUATEMODELREQUEST
DESCRIPTOR.message_types_by_name['EvaluationMetrics'] = _EVALUATIONMETRICS
DESCRIPTOR.message_types_by_name['EvaluateModelResponse'] = _EVALUATEMODELRESPONSE
DESCRIPTOR.message_types_by_name['EvaluationResultRequest'] = _EVALUATIONRESULTREQUEST
DESCRIPTOR.message_types_by_name['EvaluationResultResponse'] = _EVALUATIONRESULTRESPONSE
DESCRIPTOR.message_types_by_name['Option'] = _OPTION
DESCRIPTOR.message_types_by_name['StringInput'] = _STRINGINPUT
DESCRIPTOR.message_types_by_name['BytesInput'] = _BYTESINPUT
DESCRIPTOR.message_types_by_name['ArrIntInput'] = _ARRINTINPUT
DESCRIPTOR.message_types_by_name['ArrFloatInput'] = _ARRFLOATINPUT
DESCRIPTOR.message_types_by_name['ArrStringInput'] = _ARRSTRINGINPUT
DESCRIPTOR.message_types_by_name['StringOutput'] = _STRINGOUTPUT
DESCRIPTOR.message_types_by_name['BytesOutput'] = _BYTESOUTPUT
DESCRIPTOR.message_types_by_name['ArrIntOutput'] = _ARRINTOUTPUT
DESCRIPTOR.message_types_by_name['ArrFloatOutput'] = _ARRFLOATOUTPUT
DESCRIPTOR.message_types_by_name['ArrStringOutput'] = _ARRSTRINGOUTPUT
DESCRIPTOR.enum_types_by_name['EnumVersionInfo'] = _ENUMVERSIONINFO
DESCRIPTOR.extensions_by_name['drucker_grpc_proto_version'] = drucker_grpc_proto_version
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), dict(
  DESCRIPTOR = _HEALTHCHECKREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.HealthCheckRequest)
  ))
_sym_db.RegisterMessage(HealthCheckRequest)

HealthCheckResponse = _reflection.GeneratedProtocolMessageType('HealthCheckResponse', (_message.Message,), dict(
  DESCRIPTOR = _HEALTHCHECKRESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.HealthCheckResponse)
  ))
_sym_db.RegisterMessage(HealthCheckResponse)

ArrString = _reflection.GeneratedProtocolMessageType('ArrString', (_message.Message,), dict(
  DESCRIPTOR = _ARRSTRING,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrString)
  ))
_sym_db.RegisterMessage(ArrString)

Tensor = _reflection.GeneratedProtocolMessageType('Tensor', (_message.Message,), dict(
  DESCRIPTOR = _TENSOR,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.Tensor)
  ))
_sym_db.RegisterMessage(Tensor)

IO = _reflection.GeneratedProtocolMessageType('IO', (_message.Message,), dict(
  DESCRIPTOR = _IO,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.IO)
  ))
_sym_db.RegisterMessage(IO)

ServiceInfoRequest = _reflection.GeneratedProtocolMessageType('ServiceInfoRequest', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEINFOREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ServiceInfoRequest)
  ))
_sym_db.RegisterMessage(ServiceInfoRequest)

ServiceInfoResponse = _reflection.GeneratedProtocolMessageType('ServiceInfoResponse', (_message.Message,), dict(
  DESCRIPTOR = _SERVICEINFORESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ServiceInfoResponse)
  ))
_sym_db.RegisterMessage(ServiceInfoResponse)

UploadModelRequest = _reflection.GeneratedProtocolMessageType('UploadModelRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADMODELREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.UploadModelRequest)
  ))
_sym_db.RegisterMessage(UploadModelRequest)

SwitchModelRequest = _reflection.GeneratedProtocolMessageType('SwitchModelRequest', (_message.Message,), dict(
  DESCRIPTOR = _SWITCHMODELREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.SwitchModelRequest)
  ))
_sym_db.RegisterMessage(SwitchModelRequest)

ModelResponse = _reflection.GeneratedProtocolMessageType('ModelResponse', (_message.Message,), dict(
  DESCRIPTOR = _MODELRESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ModelResponse)
  ))
_sym_db.RegisterMessage(ModelResponse)

UploadEvaluationDataRequest = _reflection.GeneratedProtocolMessageType('UploadEvaluationDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADEVALUATIONDATAREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.UploadEvaluationDataRequest)
  ))
_sym_db.RegisterMessage(UploadEvaluationDataRequest)

UploadEvaluationDataResponse = _reflection.GeneratedProtocolMessageType('UploadEvaluationDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADEVALUATIONDATARESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.UploadEvaluationDataResponse)
  ))
_sym_db.RegisterMessage(UploadEvaluationDataResponse)

EvaluateModelRequest = _reflection.GeneratedProtocolMessageType('EvaluateModelRequest', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATEMODELREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.EvaluateModelRequest)
  ))
_sym_db.RegisterMessage(EvaluateModelRequest)

EvaluationMetrics = _reflection.GeneratedProtocolMessageType('EvaluationMetrics', (_message.Message,), dict(

  OptionEntry = _reflection.GeneratedProtocolMessageType('OptionEntry', (_message.Message,), dict(
    DESCRIPTOR = _EVALUATIONMETRICS_OPTIONENTRY,
    __module__ = 'drucker_pb2'
    # @@protoc_insertion_point(class_scope:drucker.EvaluationMetrics.OptionEntry)
    ))
  ,
  DESCRIPTOR = _EVALUATIONMETRICS,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.EvaluationMetrics)
  ))
_sym_db.RegisterMessage(EvaluationMetrics)
_sym_db.RegisterMessage(EvaluationMetrics.OptionEntry)

EvaluateModelResponse = _reflection.GeneratedProtocolMessageType('EvaluateModelResponse', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATEMODELRESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.EvaluateModelResponse)
  ))
_sym_db.RegisterMessage(EvaluateModelResponse)

EvaluationResultRequest = _reflection.GeneratedProtocolMessageType('EvaluationResultRequest', (_message.Message,), dict(
  DESCRIPTOR = _EVALUATIONRESULTREQUEST,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.EvaluationResultRequest)
  ))
_sym_db.RegisterMessage(EvaluationResultRequest)

EvaluationResultResponse = _reflection.GeneratedProtocolMessageType('EvaluationResultResponse', (_message.Message,), dict(

  Detail = _reflection.GeneratedProtocolMessageType('Detail', (_message.Message,), dict(
    DESCRIPTOR = _EVALUATIONRESULTRESPONSE_DETAIL,
    __module__ = 'drucker_pb2'
    # @@protoc_insertion_point(class_scope:drucker.EvaluationResultResponse.Detail)
    ))
  ,
  DESCRIPTOR = _EVALUATIONRESULTRESPONSE,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.EvaluationResultResponse)
  ))
_sym_db.RegisterMessage(EvaluationResultResponse)
_sym_db.RegisterMessage(EvaluationResultResponse.Detail)

Option = _reflection.GeneratedProtocolMessageType('Option', (_message.Message,), dict(
  DESCRIPTOR = _OPTION,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.Option)
  ))
_sym_db.RegisterMessage(Option)

StringInput = _reflection.GeneratedProtocolMessageType('StringInput', (_message.Message,), dict(
  DESCRIPTOR = _STRINGINPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.StringInput)
  ))
_sym_db.RegisterMessage(StringInput)

BytesInput = _reflection.GeneratedProtocolMessageType('BytesInput', (_message.Message,), dict(
  DESCRIPTOR = _BYTESINPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.BytesInput)
  ))
_sym_db.RegisterMessage(BytesInput)

ArrIntInput = _reflection.GeneratedProtocolMessageType('ArrIntInput', (_message.Message,), dict(
  DESCRIPTOR = _ARRINTINPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrIntInput)
  ))
_sym_db.RegisterMessage(ArrIntInput)

ArrFloatInput = _reflection.GeneratedProtocolMessageType('ArrFloatInput', (_message.Message,), dict(
  DESCRIPTOR = _ARRFLOATINPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrFloatInput)
  ))
_sym_db.RegisterMessage(ArrFloatInput)

ArrStringInput = _reflection.GeneratedProtocolMessageType('ArrStringInput', (_message.Message,), dict(
  DESCRIPTOR = _ARRSTRINGINPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrStringInput)
  ))
_sym_db.RegisterMessage(ArrStringInput)

StringOutput = _reflection.GeneratedProtocolMessageType('StringOutput', (_message.Message,), dict(
  DESCRIPTOR = _STRINGOUTPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.StringOutput)
  ))
_sym_db.RegisterMessage(StringOutput)

BytesOutput = _reflection.GeneratedProtocolMessageType('BytesOutput', (_message.Message,), dict(
  DESCRIPTOR = _BYTESOUTPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.BytesOutput)
  ))
_sym_db.RegisterMessage(BytesOutput)

ArrIntOutput = _reflection.GeneratedProtocolMessageType('ArrIntOutput', (_message.Message,), dict(
  DESCRIPTOR = _ARRINTOUTPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrIntOutput)
  ))
_sym_db.RegisterMessage(ArrIntOutput)

ArrFloatOutput = _reflection.GeneratedProtocolMessageType('ArrFloatOutput', (_message.Message,), dict(
  DESCRIPTOR = _ARRFLOATOUTPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrFloatOutput)
  ))
_sym_db.RegisterMessage(ArrFloatOutput)

ArrStringOutput = _reflection.GeneratedProtocolMessageType('ArrStringOutput', (_message.Message,), dict(
  DESCRIPTOR = _ARRSTRINGOUTPUT,
  __module__ = 'drucker_pb2'
  # @@protoc_insertion_point(class_scope:drucker.ArrStringOutput)
  ))
_sym_db.RegisterMessage(ArrStringOutput)

google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(drucker_grpc_proto_version)

DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\202\265\030\002v2'))
_EVALUATEMODELREQUEST.fields_by_name['data'].has_options = True
_EVALUATEMODELREQUEST.fields_by_name['data']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\030\001'))
_EVALUATIONMETRICS_OPTIONENTRY.has_options = True
_EVALUATIONMETRICS_OPTIONENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))

_HEALTH = _descriptor.ServiceDescriptor(
  name='Health',
  full_name='drucker.Health',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=2233,
  serialized_end=2309,
  methods=[
  _descriptor.MethodDescriptor(
    name='Check',
    full_name='drucker.Health.Check',
    index=0,
    containing_service=None,
    input_type=_HEALTHCHECKREQUEST,
    output_type=_HEALTHCHECKRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_HEALTH)

DESCRIPTOR.services_by_name['Health'] = _HEALTH


_DRUCKERDASHBOARD = _descriptor.ServiceDescriptor(
  name='DruckerDashboard',
  full_name='drucker.DruckerDashboard',
  file=DESCRIPTOR,
  index=1,
  options=None,
  serialized_start=2312,
  serialized_end=2830,
  methods=[
  _descriptor.MethodDescriptor(
    name='ServiceInfo',
    full_name='drucker.DruckerDashboard.ServiceInfo',
    index=0,
    containing_service=None,
    input_type=_SERVICEINFOREQUEST,
    output_type=_SERVICEINFORESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UploadModel',
    full_name='drucker.DruckerDashboard.UploadModel',
    index=1,
    containing_service=None,
    input_type=_UPLOADMODELREQUEST,
    output_type=_MODELRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SwitchModel',
    full_name='drucker.DruckerDashboard.SwitchModel',
    index=2,
    containing_service=None,
    input_type=_SWITCHMODELREQUEST,
    output_type=_MODELRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UploadEvaluationData',
    full_name='drucker.DruckerDashboard.UploadEvaluationData',
    index=3,
    containing_service=None,
    input_type=_UPLOADEVALUATIONDATAREQUEST,
    output_type=_UPLOADEVALUATIONDATARESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EvaluateModel',
    full_name='drucker.DruckerDashboard.EvaluateModel',
    index=4,
    containing_service=None,
    input_type=_EVALUATEMODELREQUEST,
    output_type=_EVALUATEMODELRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EvaluationResult',
    full_name='drucker.DruckerDashboard.EvaluationResult',
    index=5,
    containing_service=None,
    input_type=_EVALUATIONRESULTREQUEST,
    output_type=_EVALUATIONRESULTRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DRUCKERDASHBOARD)

DESCRIPTOR.services_by_name['DruckerDashboard'] = _DRUCKERDASHBOARD


_DRUCKERWORKER = _descriptor.ServiceDescriptor(
  name='DruckerWorker',
  full_name='drucker.DruckerWorker',
  file=DESCRIPTOR,
  index=2,
  options=None,
  serialized_start=2833,
  serialized_end=4748,
  methods=[
  _descriptor.MethodDescriptor(
    name='Predict_String_String',
    full_name='drucker.DruckerWorker.Predict_String_String',
    index=0,
    containing_service=None,
    input_type=_STRINGINPUT,
    output_type=_STRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_String_Bytes',
    full_name='drucker.DruckerWorker.Predict_String_Bytes',
    index=1,
    containing_service=None,
    input_type=_STRINGINPUT,
    output_type=_BYTESOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_String_ArrInt',
    full_name='drucker.DruckerWorker.Predict_String_ArrInt',
    index=2,
    containing_service=None,
    input_type=_STRINGINPUT,
    output_type=_ARRINTOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_String_ArrFloat',
    full_name='drucker.DruckerWorker.Predict_String_ArrFloat',
    index=3,
    containing_service=None,
    input_type=_STRINGINPUT,
    output_type=_ARRFLOATOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_String_ArrString',
    full_name='drucker.DruckerWorker.Predict_String_ArrString',
    index=4,
    containing_service=None,
    input_type=_STRINGINPUT,
    output_type=_ARRSTRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_Bytes_String',
    full_name='drucker.DruckerWorker.Predict_Bytes_String',
    index=5,
    containing_service=None,
    input_type=_BYTESINPUT,
    output_type=_STRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_Bytes_Bytes',
    full_name='drucker.DruckerWorker.Predict_Bytes_Bytes',
    index=6,
    containing_service=None,
    input_type=_BYTESINPUT,
    output_type=_BYTESOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_Bytes_ArrInt',
    full_name='drucker.DruckerWorker.Predict_Bytes_ArrInt',
    index=7,
    containing_service=None,
    input_type=_BYTESINPUT,
    output_type=_ARRINTOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_Bytes_ArrFloat',
    full_name='drucker.DruckerWorker.Predict_Bytes_ArrFloat',
    index=8,
    containing_service=None,
    input_type=_BYTESINPUT,
    output_type=_ARRFLOATOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_Bytes_ArrString',
    full_name='drucker.DruckerWorker.Predict_Bytes_ArrString',
    index=9,
    containing_service=None,
    input_type=_BYTESINPUT,
    output_type=_ARRSTRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrInt_String',
    full_name='drucker.DruckerWorker.Predict_ArrInt_String',
    index=10,
    containing_service=None,
    input_type=_ARRINTINPUT,
    output_type=_STRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrInt_Bytes',
    full_name='drucker.DruckerWorker.Predict_ArrInt_Bytes',
    index=11,
    containing_service=None,
    input_type=_ARRINTINPUT,
    output_type=_BYTESOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrInt_ArrInt',
    full_name='drucker.DruckerWorker.Predict_ArrInt_ArrInt',
    index=12,
    containing_service=None,
    input_type=_ARRINTINPUT,
    output_type=_ARRINTOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrInt_ArrFloat',
    full_name='drucker.DruckerWorker.Predict_ArrInt_ArrFloat',
    index=13,
    containing_service=None,
    input_type=_ARRINTINPUT,
    output_type=_ARRFLOATOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrInt_ArrString',
    full_name='drucker.DruckerWorker.Predict_ArrInt_ArrString',
    index=14,
    containing_service=None,
    input_type=_ARRINTINPUT,
    output_type=_ARRSTRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrFloat_String',
    full_name='drucker.DruckerWorker.Predict_ArrFloat_String',
    index=15,
    containing_service=None,
    input_type=_ARRFLOATINPUT,
    output_type=_STRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrFloat_Bytes',
    full_name='drucker.DruckerWorker.Predict_ArrFloat_Bytes',
    index=16,
    containing_service=None,
    input_type=_ARRFLOATINPUT,
    output_type=_BYTESOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrFloat_ArrInt',
    full_name='drucker.DruckerWorker.Predict_ArrFloat_ArrInt',
    index=17,
    containing_service=None,
    input_type=_ARRFLOATINPUT,
    output_type=_ARRINTOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrFloat_ArrFloat',
    full_name='drucker.DruckerWorker.Predict_ArrFloat_ArrFloat',
    index=18,
    containing_service=None,
    input_type=_ARRFLOATINPUT,
    output_type=_ARRFLOATOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrFloat_ArrString',
    full_name='drucker.DruckerWorker.Predict_ArrFloat_ArrString',
    index=19,
    containing_service=None,
    input_type=_ARRFLOATINPUT,
    output_type=_ARRSTRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrString_String',
    full_name='drucker.DruckerWorker.Predict_ArrString_String',
    index=20,
    containing_service=None,
    input_type=_ARRSTRINGINPUT,
    output_type=_STRINGOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrString_Bytes',
    full_name='drucker.DruckerWorker.Predict_ArrString_Bytes',
    index=21,
    containing_service=None,
    input_type=_ARRSTRINGINPUT,
    output_type=_BYTESOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrString_ArrInt',
    full_name='drucker.DruckerWorker.Predict_ArrString_ArrInt',
    index=22,
    containing_service=None,
    input_type=_ARRSTRINGINPUT,
    output_type=_ARRINTOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrString_ArrFloat',
    full_name='drucker.DruckerWorker.Predict_ArrString_ArrFloat',
    index=23,
    containing_service=None,
    input_type=_ARRSTRINGINPUT,
    output_type=_ARRFLOATOUTPUT,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Predict_ArrString_ArrString',
    full_name='drucker.DruckerWorker.Predict_ArrString_ArrString',
    index=24,
    containing_service=None,
    input_type=_ARRSTRINGINPUT,
    output_type=_ARRSTRINGOUTPUT,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_DRUCKERWORKER)

DESCRIPTOR.services_by_name['DruckerWorker'] = _DRUCKERWORKER

# @@protoc_insertion_point(module_scope)
